Installation instructions
=========================

.. toctree::
    :caption: Quick setup guide
    :maxdepth: 1
    :hidden:

    install/docker
    install/venv-debian
    install/venv-suse
    install/venv-redhat
    install/source
    install/openshift

Depending on your setup and experience, choose appropriate installation method:

* :ref:`quick-docker`, recommended for production setup.

* Virtualenv installation, recommended for production setup:

   * :doc:`install/venv-debian`
   * :doc:`install/venv-suse`
   * :doc:`install/venv-redhat`

* :ref:`quick-source`, recommended for development.

* :ref:`quick-openshift`.
